<?php

namespace App\Repositories\Order;

use App\Models\Cart;
use App\Models\Order;
use App\Models\OrderItem;
use App\Models\Product;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;

class  OrderRepositoryImpl implements OrderRepository
{
   

   public function createOrder(array $data)
{
    DB::beginTransaction();

    try {
        $userId = auth()->user()->id;

        // Retrieve cart items for the user
        $cart = Cart::where('user_id', $userId)->get();

        if ($cart->isEmpty()) {
            throw new \Exception('Your Cart Is Empty');
        }

        // Create a new order
        $order = isset($data['id']) && $data['id'] ? Order::findOrFail($data['id']) : new Order();
        $order->user_id     = $userId;
        $order->lname       = $data['lname'];
        $order->email       = $data['email'];
        $order->phoneno     = $data['phoneno'];
        $order->address1    = $data['address1'];
        $order->address2    = $data['address2'];
        $order->city        = $data['city'];
        $order->state       = $data['state'];
        $order->country     = $data['country'];
        $order->pincode     = $data['pincode'];
        $order->status_id   = $data['status_id'];
        $order->message     = $data['message'] ?? null;
        $order->tracking_no = $data['tracking_no'];
        $order->total_price = 0;
        $order->save();

        $totalPrice = 0;

        foreach ($cart as $item) {
            
         $product = Product::find($item->product_id);
          if (!$product) {
        
               throw new \Exception('Product not found for ID: ' . $item->prod_id);
            }

            $orderItem = new OrderItem();
            $orderItem->order_id = $order->id;
            $orderItem->prod_id  = $item->product_id;
            $orderItem->qty      = $item->quantity;
            $orderItem->price    = $product->price * $item->quantity;
            $orderItem->save();

            $totalPrice += $orderItem->price;
        }

        // Update total price and save the order
        $order->total_price = $totalPrice;
        $order->save();

        // Clear the cart for the user
        Cart::where('user_id', $userId)->delete();

        DB::commit();

        return $order;
    } 
    
    catch (\Exception $e) {

      DB::rollBack();
        Log::error('Order creation failed: ' . $e->getMessage());
        return $e->getMessage();
    }
}

 public function getUserOrders($paginate)
   {
      $response = [];

      try 
      {
         
         // Ensure the user is authenticated
         $user = auth()->user();
         if (!$user) 
         {

            return "User not authenticated";
         }

         // Fetch orders with relationships
         $orders = Order::with(['user', 'status', 'orderItems'])
            ->where('user_id', $user->id)
            ->paginate($paginate);

         $response['orders'] = $orders;

         return $response;
      } 
      
      catch (\Exception $e) 
      {
        return $e->getMessage();
      }
   }
}
