<?php

/**use App\Http\Controllers\BrandsController;
use App\Http\Controllers\CampaignController;
use App\Http\Controllers\CartController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\HomeController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\UserController;
use App\Http\Controllers\WishlistController;


Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
    return $request->user();
});

Route::prefix('auth')->controller(UserController::class)->group(function () {
    Route::post('/signup', 'signup');
    Route::post('/login', 'login');
});



Route::prefix('brands')->controller(BrandsController::class)->group(function () {
    Route::get('/', 'brands');
});


Route::prefix('categories')->controller(CategoryController::class)->group(function () {
    Route::get('/', 'categories');
    Route::get('/brand/{id}', 'brandCategories');
});


Route::prefix('home')->controller(HomeController::class)->group(function () {
    Route::get('/', 'homeScreenAPI');
});

Route::prefix('campaigns-products')->controller(CampaignController::class)->group(function () {
    Route::get('/{brand_id}/{category_id}', 'campaignProducts');
});

Route::prefix('user')->middleware('auth:sanctum')->controller(UserController::class)->group(function () {
    Route::get('/profile', 'getUserProfile');
    Route::put('update-profile', 'updateProfile');
});

Route::prefix('user/wishlist')->middleware('auth:sanctum')->controller(WishlistController::class)->group(function () {
    Route::post('/add', 'addToWishlist');
});


Route::prefix('cart')->middleware('auth:sanctum')->controller(CartController::class)->group(function () {
    Route::post('add-to-cart', 'addToCart');
    Route::get('get-user-cart', 'getUserCart');
    Route::post('checkout', 'checkout');
}); **/


use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\UserController;
use App\Http\Controllers\BrandsController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\CampaignController;
use App\Http\Controllers\WishlistController;
use App\Http\Controllers\CartController;
use App\Http\Controllers\OrderController;
use Laravel\Sanctum\Http\Controllers\CsrfCookieController;


/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Define API routes for the application. These routes are grouped and
| organized for better readability and maintainability.
|
*/

// Authenticated User Routes

Route::get('/sanctum/csrf-cookie', function () {
    return response()->json(['message' => 'CSRF cookie set']);
});
Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
    return $request->user();
});



// Authentication Routes
Route::prefix('auth')->group(function () {
    Route::controller(UserController::class)->group(function () {
        Route::post('/signup', 'signup');
        Route::post('/login', 'login');
    });
});

// Brand Routes
Route::prefix('brands')->group(function () {
    Route::controller(BrandsController::class)->group(function () {
        Route::get('/', 'brands');
    });
});

// Category Routes
Route::prefix('categories')->group(function () {
    Route::controller(CategoryController::class)->group(function () {
        Route::get('/', 'categories');
        Route::get('/brand/{id}', 'brandCategories');
    });
});

// Home Routes
Route::prefix('home')->group(function () {
    Route::controller(HomeController::class)->group(function () {
        Route::get('/', 'homeScreenAPI');
    });
});

// Campaign Routes
Route::prefix('campaigns-products')->group(function () {
    Route::controller(CampaignController::class)->group(function () {
        Route::get('/{brand_id}/{category_id}', 'campaignProducts');
    });
});

// User Profile Routes
Route::prefix('user')->middleware('auth:sanctum')->group(function () {
    Route::controller(UserController::class)->group(function () {
        Route::get('/profile', 'getUserProfile');
        Route::put('/update-profile', 'updateProfile');
    });
});

// Wishlist Routes
Route::prefix('user/wishlist')->middleware('auth:sanctum')->group(function () {

    Route::controller(WishlistController::class)->group(function () {
        Route::post('/add', 'addToWishlist');
    });
});

// Cart Routes
Route::prefix('cart')->middleware('auth:sanctum')->group(function () {

    Route::controller(CartController::class)->group(function () {
        Route::post('/add-to-cart', 'addToCart');
        Route::get('/view-cart', 'viewCart');
        Route::get('/remove-cart', 'removeFromCart');
        Route::get('/clear-cart', 'clearCart');
        // Route::get('/get-user-cart', 'getUserCart');
        //Route::post('/checkout', 'checkout');
    });
});




//Order Routes
Route::prefix('order')->middleware('auth:sanctum')->group(function () {

    Route::controller(OrderController::class)->group(function () {
        Route::post('/place-holder-order', 'createOrder');
        Route::get('/orders-by-user', 'getUserOrders');
    });
});
